# Generated by roxygen2: do not edit by hand

S3method(wt_data,default)
S3method(wt_data,wiki_id)
export(wt_data)
export(wt_data_id)
export(wt_wiki_page)
export(wt_wiki_page_parse)
export(wt_wiki_url_build)
export(wt_wiki_url_parse)
export(wt_wikicommons)
export(wt_wikicommons_parse)
export(wt_wikicommons_search)
export(wt_wikipedia)
export(wt_wikipedia_parse)
export(wt_wikipedia_search)
export(wt_wikispecies)
export(wt_wikispecies_parse)
export(wt_wikispecies_search)
