#' Taxonomic Information from Wikipedia
#'
#' @name wikitaxa-package
#' @aliases wikitaxa
#' @docType package
#' @author Scott Chamberlain \email{myrmecocystus@@gmail.com}
#' @author Ethan Welty
#' @keywords package
NULL

#' List of Wikipedias
#'
#' data.frame of 295 rows, with 3 columns:
#' \itemize{
#'  \item language - language
#'  \item language_local - language in local name
#'  \item wiki - langugae code for the wiki
#' }
#'
#' From <https://meta.wikimedia.org/wiki/List_of_Wikipedias>
#'
#' @name wikipedias
#' @docType data
#' @keywords data
NULL
